@@ -1,8 +1,9 @@
 /***
 |''Name''|TiddlySpaceBackstage|
-|''Version''|0.6.0|
+|''Version''|0.6.3|
 |''Description''|Provides a TiddlySpace version of the backstage and a homeLink, and followSpace macro|
 |''Status''|@@beta@@|
+|''Contributors''|Jon Lister, Jon Robson, Colm Britton|
 |''Source''|http://github.com/TiddlySpace/tiddlyspace/raw/master/src/plugins/TiddlySpaceBackstage.js|
 |''Requires''|TiddlySpaceConfig ImageMacroPlugin TiddlySpaceViewTypes|
 !Code
@@ -10,10 +11,15 @@
 //{{{
 (function($) {
 
-var disabled_tabs_for_nonmembers = ["PluginManager", "Backstage##FileImport", "Backstage##BatchOps",
-	"Backstage##SpaceMembers", "TiddlySpaceTabs##Private", "TiddlySpaceTabs##Drafts"];
+if(!config.extensions.tiddlyweb.status.tiddlyspace_version) { // unplugged
+	config.extensions.tiddlyweb.status.tiddlyspace_version = "<unknown>";
+}
+var disabled_tabs_for_nonmembers = ["PluginManager", "Backstage##FileImport",
+	"Backstage##BatchOps", "Backstage##SpaceMembers",
+	"TiddlySpaceTabs##Private", "TiddlySpaceTabs##Drafts"];
 var tweb = config.extensions.tiddlyweb;
 var tiddlyspace = config.extensions.tiddlyspace;
+var currentSpace = tiddlyspace.currentSpace.name;
 var imageMacro = config.macros.image;
 
 if(config.options.chkBackstage === undefined) {
@@ -27,14 +33,12 @@ config.tasks.login = {
 
 config.tasks.user = {
 	text: "user: ",
-	tooltip: "user control panel",
-	content: "<<tiddler Backstage##User>>"
+	tooltip: "user control panel"
 };
 
 config.tasks.space = {
 	text: "space: ",
 	tooltip: "space control panel",
-	content: "<<tiddler Backstage##Space>>",
 	className: "right"
 };
 
@@ -42,8 +46,16 @@ config.tasks.tiddlyspace = {
 	text: "",
 	tooltip: "",
 	content: "<<tiddler Backstage##Menu>>"
-}
+};
 
+if(window.location.protocol == "file:") {
+	config.unplugged = true; // TODO: move into extensions.tiddly{web/space} namespace!?
+	config.tasks.space.content = "<<tiddler Backstage##SpaceUnplugged>>";
+	config.tasks.user.content = "<<tiddler Backstage##UserUnplugged>>";
+} else {
+	config.tasks.space.content = "<<tiddler Backstage##Space>>";
+	config.tasks.user.content = "<<tiddler Backstage##User>>";
+}
 config.backstageTasks = ["login", "tiddlyspace", "user", "space"];
 
 config.messages.backstage.prompt = "";
@@ -52,14 +64,16 @@ var _show = backstage.show;
 backstage.show = function() {
 	// selectively hide backstage tasks and tabs based on user status
 	var tasks = $("#backstageToolbar .backstageTask").show();
-	tweb.getUserInfo(function(user) {
-		if(user.anon) {
-			$(".task_user", tasks).hide();
-			tiddlyspace.disableTab(disabled_tabs_for_nonmembers);
-		} else {
-			$(".task_login", tasks).hide();
-		}
-	});
+	if(!config.unplugged) {
+		tweb.getUserInfo(function(user) {
+			if(user.anon) {
+				$(".task_user", tasks).hide();
+				tiddlyspace.disableTab(disabled_tabs_for_nonmembers);
+			} else {
+				$(".task_login", tasks).hide();
+			}
+		});
+	}
 	// display backstage
 	return _show.apply(this, arguments);
 };
@@ -67,7 +81,6 @@ if(readOnly) {
 	tiddlyspace.disableTab(disabled_tabs_for_nonmembers);
 }
 
-var _init = backstage.init;
 var tasks = config.tasks;
 var commonUrl = "/bags/common/tiddlers/%0";
 
@@ -78,7 +91,21 @@ backstage.tiddlyspace = {
 	locale: {
 		member: "You are a member of this space.",
 		nonmember: "You are a non-member of this space.",
-		loggedout: "You are currently logged out of TiddlySpace."
+		loggedout: "You are currently logged out of TiddlySpace.",
+		unplugged: "You are unplugged."
+	},
+	checkSyncStatus: function() {
+		var bs = backstage.tiddlyspace;
+		var t = store.filterTiddlers("[is[unsynced]]");
+		var unsyncedList = $("#backstage .tiddlyspaceMenu .unsyncedList");
+		if(t.length > 0 && !readOnly) {
+			bs.tweakMiddleButton("unsyncedIcon");
+			$("#backstage").addClass("unsyncedChanges");
+		} else {
+			bs.tweakMiddleButton();
+			$("#backstage").removeClass("unsyncedChanges");
+		}
+		story.refreshAllTiddlers();
 	},
 	userButton: function(backstageArea, user) {
 		// override user button (logged in) to show username
@@ -89,7 +116,8 @@ backstage.tiddlyspace = {
 			$("<span />").text(tasks.user.text).appendTo(userBtn);
 			$("<span />").addClass("txtUserName").text(user.name).appendTo(userBtn);
 			var container = $("<span />").appendTo(userBtn)[0];
-			tiddlyspace.renderAvatar(container, user.name, { imageOptions: { imageClass:"userSiteIcon", height: 24, width: 24 },
+			tiddlyspace.renderAvatar(container, user.name,
+				{ imageOptions: { imageClass:"userSiteIcon", height: 24, width: 24 },
 				labelOptions: { include: false } });
 		}
 	},
@@ -98,51 +126,58 @@ backstage.tiddlyspace = {
 		var altText = $(showBtn).text();
 		$(showBtn).empty();
 		imageMacro.renderImage(showBtn, "backstage.svg",
-			{ altImage: commonUrl.format(["backstage.png"]), alt: altText, width: 60, height: 60 });
+			{ altImage: commonUrl.format("backstage.png"), alt: altText, width: 60, height: 60 });
 	},
 	hideButton: function() {
 		var hideBtn = $("#backstageHide")[0];
 		altText = $(hideBtn).text();
 		$(hideBtn).empty();
 		imageMacro.renderImage(hideBtn, "close.svg",
-			{ altImage: commonUrl.format(["close.png"]), alt: altText, width: 24, height: 24 });
+			{ altImage: commonUrl.format("close.png"), alt: altText, width: 24, height: 24 });
 	},
-	middleButton: function(backstageArea) {
-		var locale = backstage.tiddlyspace.locale;
+	middleButton: function(backstageArea, user) {
+		var bs = backstage.tiddlyspace;
 		var backstageToolbar = $("#backstageToolbar", backstageArea)[0];
-		var backstageLogo = $("#[task=tiddlyspace]").empty()[0];
-		var iconName = readOnly ? "publicIcon" : "privateAndPublicIcon";
-		var space = tiddlyspace.currentSpace.name;
-		tweb.getUserInfo(function(user) {
-			if(!user.anon) {
-				config.messages.memberStatus = readOnly ? locale.nonmember : locale.member;
-			} else {
-				config.messages.memberStatus = locale.loggedout;
-			}
-		});
-		imageMacro.renderImage(backstageLogo, iconName, { width: 24, height: 24 });
-		$(".image", backstageLogo);
+		if(user.unplugged) {
+			config.messages.memberStatus = bs.locale.unplugged;
+		} else if(!user.anon) {
+			config.messages.memberStatus = readOnly ? bs.locale.nonmember : bs.locale.member;
+		} else {
+			config.messages.memberStatus = bs.locale.loggedout;
+		}
 		// construct the tiddlyspace logo
+		var backstageLogo = $("#[task=tiddlyspace]").empty()[0];
+		$("<span />").addClass("iconContainer").appendTo(backstageLogo);
 		$('<span class="logoText"><span class="privateLightText">tiddly</span>' +
 				'<span class="publicLightText">space</span></span>').
 			appendTo(backstageLogo);
+		bs.tweakMiddleButton();
+	},
+	tweakMiddleButton: function(iconName) {
+		var backstageLogo = $("#[task=tiddlyspace] .iconContainer").empty()[0];
+		var backstageToolbar = $("#backstageToolbar");
+		var plugin = backstage.tiddlyspace;
+		if(!iconName) {
+			iconName = readOnly ? "publicIcon" : "privateAndPublicIcon";
+		}
+		config.macros.image.renderImage(backstageLogo, iconName, { width: 24, height: 24 });
 	},
 	spaceButton: function(backstageArea) {
 		// override space button to show SiteIcon
-		var spaceName = tiddlyspace.currentSpace.name;
 		var btn = $("[task=space]", backstageArea);
 		btn.empty();
-		tiddlyspace.renderAvatar(btn[0], spaceName, { imageOptions: { imageClass:"spaceSiteIcon", height: 24, width: 24 },
+		tiddlyspace.renderAvatar(btn[0], currentSpace,
+			{ imageOptions: { imageClass:"spaceSiteIcon", height: 24, width: 24 },
 			labelOptions: { include: false } });
 		$("<span />").text(tasks.space.text).appendTo(btn);
-		$("<span />").addClass("spaceName").text(spaceName).appendTo(btn);
+		$("<span />").addClass("spaceName").text(currentSpace).appendTo(btn);
 	},
 	loginButton: function(backstageArea, user) {
 		var loginBtn = $("[task=login]", backstageArea).empty();
 		if(user.anon) {
 			$("<span />").text(tasks.login.text).appendTo(loginBtn);
 			var container = $("<span />").appendTo(loginBtn)[0];
-			imageMacro.renderImage(container, commonUrl.format(["defaultUserIcon"]),
+			imageMacro.renderImage(container, commonUrl.format("defaultUserIcon"),
 				{ imageClass:"userSiteIcon", height: 24, width: 24 });
 		} else {
 			loginBtn.remove();
@@ -153,23 +188,32 @@ backstage.tiddlyspace = {
 		for(var i = 0; i < tasks.length; i++) {
 			var btn = $(tasks[i]);
 			var taskName = btn.attr("task");
-			btn.addClass("task_%0".format([taskName]));
+			btn.addClass("task_%0".format(taskName));
 		}
 	}
 };
+
+var _init = backstage.init;
 backstage.init = function() {
 	_init.apply(this, arguments);
-	tweb.getUserInfo(function(user) {
+	var init = function(user) {
 		var backstageArea = $("#backstageArea")[0];
-		var tiddlyspace_b = backstage.tiddlyspace;
-		tiddlyspace_b.userButton(backstageArea, user);
-		tiddlyspace_b.showButton();
-		tiddlyspace_b.hideButton();
-		tiddlyspace_b.middleButton(backstageArea);
-		tiddlyspace_b.spaceButton(backstageArea);
-		tiddlyspace_b.loginButton(backstageArea, user);
-		tiddlyspace_b.addClasses(backstageArea); // for IE styling purposes
-	});
+		var bs = backstage.tiddlyspace;
+		store.addNotification(null, bs.checkSyncStatus);
+		bs.userButton(backstageArea, user);
+		bs.showButton();
+		bs.hideButton();
+		bs.middleButton(backstageArea, user);
+		bs.spaceButton(backstageArea);
+		bs.loginButton(backstageArea, user);
+		bs.addClasses(backstageArea); // for IE styling purposes
+		bs.checkSyncStatus();
+	};
+	if(!config.unplugged) {
+		tweb.getUserInfo(init);
+	} else {
+		init({ unplugged: true, anon: false, name: config.options.txtUserName });
+	}
 };
 
 var home = config.macros.homeLink = {
@@ -179,7 +223,7 @@ var home = config.macros.homeLink = {
 	handler: function(place) {
 		var container = $("<span />").appendTo(place)[0];
 		tweb.getUserInfo(function(user) {
-			if(!user.anon && user.name != tiddlyspace.currentSpace.name) {
+			if(!user.anon && user.name != currentSpace) {
 				createSpaceLink(container, user.name, null, home.locale.linkText);
 			}
 		});
@@ -193,22 +237,21 @@ var followLink = config.macros.followSpace = {
 	paramifiedLink: function(container, space, title, label, paramifier) {
 		tweb.getStatus(function(status) {
 			var host = config.extensions.tiddlyspace.getHost(status.server_host, space);
-			var url = "%0/#%1:[[%2]]".format([host, paramifier, title]);
+			var url = "%0/#%1:[[%2]]".format(host, paramifier, title);
 			label = label ? label : title;
 			$("<a />").attr("href", url).text(label).appendTo(container);
 		});
 	},
 	make: function(container, username, space) {
 		followLink.paramifiedLink(container, username, "@" + space,
-			followLink.locale.label.format([space]), "follow");
+			followLink.locale.label.format(space), "follow");
 	},
 	handler: function(place) {
 		var container = $("<span />").appendTo(place)[0];
 		tweb.getUserInfo(function(user) {
-			var space = tiddlyspace.currentSpace.name;
 			var username = user.name;
-			if(!user.anon && space != username) {
-				followLink.make(place, username, space);
+			if(!user.anon && currentSpace != username) {
+				followLink.make(place, username, currentSpace);
 			}
 		});
 	}
@@ -217,11 +260,21 @@ var followLink = config.macros.followSpace = {
 config.macros.exportSpace = {
 	handler: function(place, macroName, params) {
 		var filename = params[0] ||
-			"/?download=%0.html".format([tiddlyspace.currentSpace.name]);
+			"/?download=%0.html".format(currentSpace);
 		$('<a class="button">download</a>'). // XXX: i18n
 			attr("href", filename).appendTo(place);
 	}
 };
 
+$.extend(config.messages, {
+	syncExplanation: "You are currently viewing an offline version of this TiddlySpace. From here you can sync your offline copy with the online version.",
+	syncListHeading: "Unsaved tiddlers listed below"});
+
+var _reportSuccess = config.extensions.ServerSideSavingPlugin.reportSuccess;
+config.extensions.ServerSideSavingPlugin.reportSuccess = function() {
+	backstage.tiddlyspace.checkSyncStatus();
+	_reportSuccess.apply(this, arguments);
+};
+
 })(jQuery);
 //}}}
